@@ -7,6 +7,7 @@ from itsdangerous import JSONWebSignatureSerializer as JWS
 from itsdangerous import BadSignature, SignatureExpired
 
 from . import consts, core
+from .consts import LOGS
 
 import random
 import string
@@ -164,7 +165,16 @@ class User(core.LdapObject):
         return Position(self.employeeType).department
 
     @staticmethod
-    def create(name, email, department, registration_number, role, **kwargs):
+    def create(
+            name,
+            email,
+            department,
+            registration_number,
+            role,
+            mobile,
+            manager,
+            **kwargs
+            ):
 
         users = User.all()
         for user in users:
@@ -209,6 +219,8 @@ class User(core.LdapObject):
                     first_name = ''
                 first_name = kwargs.get('givenName', first_name)
                 last_name = kwargs.get('sn', last_name)
+                mobile = kwargs.get('mobile', mobile)
+                manager = kwargs.get('manager', manager)
             data = {
                 'uid': email,
                 'mail': email,
@@ -219,6 +231,10 @@ class User(core.LdapObject):
                 'employeeNumber': registration_number,
                 'objectClass': 'inetOrgPerson',
                 }
+            if mobile:
+                data['mobile'] = mobile
+            if manager:
+                data['manager'] = manager
             print(data)
             data = [
                 (key, value.encode('utf-8')) for key, value in data.items()
@@ -227,6 +243,7 @@ class User(core.LdapObject):
             subdomain = kwargs.get('subdomain')
             if subdomain:
                 domain = 'ou={},{}'.format(subdomain, domain)
+            LOGS.logger.info(data)
             core.ldap_conn('add_s', 'cn={0},{1}'.format(name, domain), data)
             # utilisateur créé
             user = User(email)
